@@ -21,7 +21,7 @@
 
 /* Prologue {{{1 */
 
-#include "gtimezoneprivate.h"
+#include "gtimezone.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -44,6 +44,22 @@
  * #GTimeZone is a structure that represents a time zone, at no
  * particular point in time.  It is refcounted and immutable.
  *
+ * A time zone contains a number of intervals.  Each interval has
+ * an abbreviation to describe it, an offet to UTC and a flag indicating
+ * if the daylight savings time is in effect during that interval.  A
+ * time zone always has at least one interval -- interval 0.
+ *
+ * Every UTC time is contained within exactly one interval, but a given
+ * local time may be contained within zero, one or two intervals (due to
+ * incontinuities associated with daylight savings time).
+ *
+ * An interval may refer to a specific period of time (eg: the duration
+ * of daylight savings time during 2010) or it may refer to many periods
+ * of time that share the same properties (eg: all periods of daylight
+ * savings time).  It is also possible (usually for political reasons)
+ * that some properties (like the abbreviation) change between intervals
+ * without other properties changing.
+ *
  * #GTimeZone is available since GLib 2.26.
  */
 
@@ -189,7 +205,7 @@ g_time_zone_ref (GTimeZone *tz)
  *  - hh is 00 to 23
  *  - mm is 00 to 59
  */
-gboolean
+static gboolean
 parse_time (const gchar *time,
             gint32      *offset)
 {
@@ -225,7 +241,7 @@ parse_time (const gchar *time,
   return *time == '\0';
 }
 
-gboolean
+static gboolean
 parse_constant_offset (const gchar *name,
                        gint32      *offset)
 {
